==> forestry_1.9.4-5.0.4.118-sources.jar: forestry/mail/gui/GuiTrader.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.mail.gui;

import net.minecraft.entity.player.InventoryPlayer;

import forestry.core.config.Constants;
import forestry.core.gui.GuiForestry;
import forestry.core.utils.Translator;
import forestry.mail.tiles.TileTrader;

public class GuiTrader extends GuiForestry<ContainerTrader, TileTrader> {

	public GuiTrader(InventoryPlayer inventoryplayer, TileTrader tile) {
		super(Constants.TEXTURE_PATH_GUI + "/mailtrader2.png", new ContainerTrader(inventoryplayer, tile), tile);
		this.field_146999_f = 226;
		this.field_147000_g = 220;
	}

	@Override
	protected void func_146979_b(int mouseX, int mouseY) {
		String name = Translator.translateToLocal(inventory.getUnlocalizedTitle());
		this.field_146289_q.func_78276_b(name, textLayout.getCenteredOffset(name), 6, fontColor.get("gui.mail.text"));

		String receive = Translator.translateToLocal("for.gui.mail.receive");
		this.field_146289_q.func_78276_b(receive, textLayout.getCenteredOffset(receive, 70) + 51, 45, fontColor.get("gui.mail.text"));

		String send = Translator.translateToLocal("for.gui.mail.send");
		this.field_146289_q.func_78276_b(send, textLayout.getCenteredOffset(send, 70) + 51, 99, fontColor.get("gui.mail.text"));

		super.func_146979_b(mouseX, mouseY);
	}

	@Override
	protected void func_146976_a(float var1, int mouseX, int mouseY) {
		super.func_146976_a(var1, mouseX, mouseY);

		field_146289_q.func_78276_b(container.getAddress().getName(), field_147003_i + 19, field_147009_r + 22, fontColor.get("gui.mail.text"));
	}
}

==> forestry_1.9-5.0.0.58-sources.jar: forestry/mail/gui/GuiTrader.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.mail.gui;

import net.minecraft.entity.player.InventoryPlayer;

import forestry.core.config.Constants;
import forestry.core.gui.GuiForestry;
import forestry.core.utils.Translator;
import forestry.mail.tiles.TileTrader;

public class GuiTrader extends GuiForestry<ContainerTrader, TileTrader> {

	public GuiTrader(InventoryPlayer inventoryplayer, TileTrader tile) {
		super(Constants.TEXTURE_PATH_GUI + "/mailtrader2.png", new ContainerTrader(inventoryplayer, tile), tile);
		this.xSize = 226;
		this.ySize = 220;
	}

	@Override
	protected void drawGuiContainerForegroundLayer(int mouseX, int mouseY) {
		String name = Translator.translateToLocal(inventory.getUnlocalizedTitle());
		this.fontRendererObj.drawString(name, textLayout.getCenteredOffset(name), 6, fontColor.get("gui.mail.text"));

		String receive = Translator.translateToLocal("for.gui.mail.receive");
		this.fontRendererObj.drawString(receive, textLayout.getCenteredOffset(receive, 70) + 51, 45, fontColor.get("gui.mail.text"));

		String send = Translator.translateToLocal("for.gui.mail.send");
		this.fontRendererObj.drawString(send, textLayout.getCenteredOffset(send, 70) + 51, 99, fontColor.get("gui.mail.text"));

		super.drawGuiContainerForegroundLayer(mouseX, mouseY);
	}

	@Override
	protected void drawGuiContainerBackgroundLayer(float var1, int mouseX, int mouseY) {
		super.drawGuiContainerBackgroundLayer(var1, mouseX, mouseY);

		fontRendererObj.drawString(container.getAddress().getName(), guiLeft + 19, guiTop + 22, fontColor.get("gui.mail.text"));
	}
}
